==> drools-wb-7.2.0.Final-project-sources.tar.gz: drools-wb-7.2.0.Final/drools-wb-services/drools-wb-verifier/drools-wb-verifier-api/src/test/java/org/drools/workbench/services/verifier/api/client/index/ConditionTest.java <==
/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.workbench.services.verifier.api.client.index;

import org.drools.workbench.services.verifier.api.client.AnalyzerConfigurationMock;
import org.drools.workbench.services.verifier.api.client.index.keys.Values;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.*;
import static org.mockito.Mockito.*;

public class ConditionTest {

    private Condition condition;

    @Before
    public void setUp() throws
                        Exception {
        condition = new Condition( mock( Column.class ),
                                   ConditionSuperType.FIELD_CONDITION,
                                   new Values( 1 ),
                                   new AnalyzerConfigurationMock() ) {

        };
    }

    @Test
    public void valueSet() throws
                           Exception {
        assertEquals( 1,
                      condition.getValues()
                              .size() );
        assertEquals( 1,
                      condition.getValues()
                              .iterator()
                              .next() );
    }

    @Test
    public void changeValue() throws
                              Exception {
        condition.setValue( new Values( 2 ) );

        assertEquals( 1,
                      condition.getValues()
                              .size() );
        assertEquals( 2,
                      condition.getValues()
                              .iterator()
                              .next() );
    }
}

==> drools-wb-7.9.0.Final-project-sources.tar.gz: drools-wb-7.9.0.Final/drools-wb-services/drools-wb-verifier/drools-wb-verifier-api/src/test/java/org/drools/workbench/services/verifier/api/client/index/ConditionTest.java <==
/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.workbench.services.verifier.api.client.index;

import org.drools.workbench.services.verifier.api.client.AnalyzerConfigurationMock;
import org.drools.workbench.services.verifier.api.client.index.keys.Values;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.mockito.Mockito.mock;

public class ConditionTest {

    private Condition condition;

    @Before
    public void setUp() throws
                        Exception {
        condition = new Condition( mock( Column.class ),
                                   ConditionSuperType.FIELD_CONDITION,
                                   new Values( 1 ),
                                   new AnalyzerConfigurationMock() ) {

        };
    }

    @Test
    public void valueSet() throws
                           Exception {
        assertEquals( 1,
                      condition.getValues()
                              .size() );
        assertEquals( 1,
                      condition.getValues()
                              .iterator()
                              .next() );
    }

    @Test
    public void changeValue() throws
                              Exception {
        condition.setValue( new Values( 2 ) );

        assertEquals( 1,
                      condition.getValues()
                              .size() );
        assertEquals( 2,
                      condition.getValues()
                              .iterator()
                              .next() );
    }
}
